@@ -1,6 +1,5 @@
 /*******************************************************************************
 
- /*
  This file is a part of Fahrplan for maemo 2009-2010
 
  This program is free software; you can redistribute it and/or modify
@@ -22,7 +21,7 @@
  ============================================================================
  Name        : main.c
  Author      : smurfy
- Version     : 0.0.2
+ Version     : 0.0.3
  Description : Fahrplan application for german trains
  ============================================================================
  */
@@ -48,7 +47,7 @@
 #include "localisation.h"
 
 #define APP_NAME "fahrplan"
-#define APP_VER "0.0.2"
+#define APP_VER "0.0.3"
 #define APP_SERVICE "com.nokia.fahrplan"
 #define APP_METHOD "/com/nokia/fahrplan"
 /* end defines */
@@ -59,6 +58,7 @@ struct _AppData {
 	HildonProgram *program;
 	HildonWindow *window;
 	HildonWindow *resultWindow;
+	HildonWindow *detailsWindow;
 
 	GtkWidget *verticalContainer;
 	GtkWidget *fromContainer;
@@ -81,8 +81,14 @@ struct _AppData {
 	GtkWidget *currentSelector;
 	GtkWidget *currentTmpPicker;
 	GtkWidget *currentSelectorFor;
-	GtkWidget *currentPannableArea;
-	GtkWidget *currentPannableAreaVbox;
+	GtkWidget *currentResultPannableArea;
+	GtkWidget *currentResultSelector;
+	GtkListStore   *currentResultModelStore;
+	GtkWidget *currentDetailsPannableArea;
+	GtkWidget *currentDetailsSelector;
+	GtkListStore   *currentDetailsModelStore;
+
+	char currentResultBaseUrl[255];
 };
 
 /**
@@ -118,13 +124,17 @@ static size_t copyDataBuffer(void *ptr, size_t size, size_t nmemb, void *ctx) {
 static void getResultValues(xmlNode * a_node, AppData *data) {
 	xmlNode *cur_node = NULL;
 	xmlNode *tmp_node = NULL;
+	xmlAttr *cur_attribute = NULL;
 
 	int num = 0;
 	int found = 0;
-	char timeStr[100] = "";
+	char fromTimeStr[100] = "";
+	char toTimeStr[100] = "";
 	char *otherStr = "";
 	char *changeStr = "";
+	char *warningStr = "";
 	char *trainTypeStr = "";
+	char trainUrlStr[255] = "";
 
 	for (cur_node = a_node; cur_node; cur_node = cur_node->next) {
 
@@ -137,6 +147,16 @@ static void getResultValues(xmlNode * a_node, AppData *data) {
 
 				if (!strcmp(cur_node->children->name, "a")) {
 
+					for (cur_attribute = cur_node->children->properties; cur_attribute; cur_attribute
+													= cur_attribute->next) {
+
+						if (!strcmp(cur_attribute->name, "href")) {
+
+							strcat(trainUrlStr, cur_attribute->children->content);
+						}
+					}
+
+
 					found = 1;
 
 					int addTo = 0;
@@ -145,15 +165,41 @@ static void getResultValues(xmlNode * a_node, AppData *data) {
 
 						if (!strcmp(tmp_node->name, "text")) {
 
-							strcat(timeStr, tmp_node->content);
-							if (!addTo) {
-								strcat(timeStr, _(" to "));
+							if (addTo) {
+
+								strcat(toTimeStr, tmp_node->content);
+							} else {
+
+								strcat(fromTimeStr, tmp_node->content);
 							}
 							addTo = 1;
 						}
 					}
 
 				}
+				break;
+			case 1:
+
+				if (!strcmp(cur_node->children->name, "img")) {
+
+					if (!strcmp(cur_node->children->properties->children->content, "/v/660/img/achtung_rot_16x16.gif")) {
+
+						warningStr = _("<b>Warning, possible changes</b>");
+					}
+				}
+
+				if (!strcmp(cur_node->children->name, "span")) {
+
+					if (!strcmp(cur_node->children->children->content, "+0")) {
+
+						warningStr = _("On Time");
+					} else {
+
+						warningStr = cur_node->children->children->content;
+					}
+				}
+
+
 				break;
 			case 2:
 
@@ -181,16 +227,44 @@ static void getResultValues(xmlNode * a_node, AppData *data) {
 
 	if (found) {
 
-		char infoLabel[100];
+		if (trainUrlStr) {
 
-		sprintf(infoLabel, "%s %s %s (%s %s)", timeStr, _(" with "),
-				trainTypeStr, changeStr, _("transfers"));
-		GtkWidget *infoButton;
-		infoButton = gtk_button_new_with_label(infoLabel);
+			char infoLabel[100];
+			char urlLabel[100];
 
-		gtk_box_pack_start(GTK_BOX (data->currentPannableAreaVbox), infoButton,
-				TRUE, TRUE, 0);
+			char *transfersStr= _("transfers");
 
+			if (atoi(changeStr)==1) {
+
+				transfersStr= _("transfer");
+			}
+
+			if (!strcmp(warningStr, "")) {
+
+				sprintf(infoLabel, "<b>%s - %s</b> %s (%s %s)", fromTimeStr, toTimeStr, trainTypeStr, changeStr, transfersStr);
+			} else {
+
+				sprintf(infoLabel, "<b>%s - %s</b> %s (%s %s)\n%s", fromTimeStr, toTimeStr, trainTypeStr, changeStr, transfersStr ,warningStr);
+			}
+
+			GtkTreeIter    iter;
+
+			/* Append a row and fill in some data */
+			gtk_list_store_append (data->currentResultModelStore, &iter);
+			gtk_list_store_set (data->currentResultModelStore, &iter,
+							  0, infoLabel,
+							  -1);
+
+			gint num  = gtk_tree_model_iter_n_children (data->currentResultModelStore, NULL);
+
+			sprintf(urlLabel, "URL%d", num);
+
+			gchar *trainUrlGChar;
+
+			trainUrlGChar = g_strdup_printf("%s", trainUrlStr);
+
+			g_object_set_data(G_OBJECT(data->currentResultSelector), urlLabel, trainUrlGChar);
+		}
 		/* g_debug("stuff: %s , %s , %s ", timeStr, changeStr, trainTypeStr); */
 	}
 }
@@ -240,17 +314,694 @@ char* getIdForName(char *name, char * dataText, AppData *data) {
 			}
 		}
 	}
+}
 
+/**
+ * Loader function for last and earlier result page call
+ */
+void loadResultPage(char* targetUrl, AppData *data) {
+
+	/* Start Curl search */
+	CURL *curl;
+	CURLcode res;
+	char buf[50000];
+	struct CURLData curldata;
+
+	curldata.buf = buf;
+	curldata.size = 50000;
+	curldata.pos = 0;
+
+	curl = curl_easy_init();
+	if (curl) {
+
+		g_debug("query: %s", targetUrl);
+
+		curl_easy_setopt(curl, CURLOPT_URL, targetUrl);
+		curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, &copyDataBuffer);
+		curl_easy_setopt(curl, CURLOPT_WRITEDATA, &curldata);
+		curl_easy_setopt(curl, CURLOPT_FAILONERROR, 1);
+		curl_easy_setopt(curl, CURLOPT_TIMEOUT, 150L);
+		curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT, 15L);
+
+		res = curl_easy_perform(curl);
+
+		if (res != CURLE_OK) {
+
+			hildon_banner_show_information(
+					GTK_WIDGET(data->window),
+					NULL,
+					_("An error occured while requesting data over the internet."));
+			gtk_widget_hide(data->currentDialog);
+			gtk_widget_destroy(data->currentDialog);
+			data->currentDialog = NULL;
+
+			g_debug("CURL_ERROR: %d", res);
+
+			return;
+		}
+
+		parseSearchResult(curldata.buf, data);
+	}
+}
+
+/**
+ * Handles the later Button Click
+ */
+void laterClicked(HildonButton * button, AppData *data) {
+
+	gtk_widget_destroy(GTK_WIDGET(data->resultWindow));
+
+	char url[260] = "";
+	strcat(url, data->currentResultBaseUrl);
+	strcat(url, "e=1");
+	loadResultPage(url, data);
+}
+
+/**
+ * Handles the earlier Button Click
+ */
+void earlierClicked(HildonButton * button, AppData *data) {
+
+	gtk_widget_destroy(GTK_WIDGET(data->resultWindow));
+
+	char url[260] = "";
+	strcat(url, data->currentResultBaseUrl);
+	strcat(url, "e=2");
+	loadResultPage(url, data);
+}
+
+/**
+ * Loader function for the details page
+ *
+ * @todo: Finish Up for 0.0.4
+ */
+void loadDetails(char* targetUrl, AppData *data) {
+
+	return;
+
+	/* Start Curl search */
+	CURL *curl;
+	CURLcode res;
+	char buf[50000];
+	struct CURLData curldata;
+
+	curldata.buf = buf;
+	curldata.size = 50000;
+	curldata.pos = 0;
+
+	curl = curl_easy_init();
+	if (curl) {
+
+		g_debug("query: %s", targetUrl);
+
+		curl_easy_setopt(curl, CURLOPT_URL, targetUrl);
+		curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, &copyDataBuffer);
+		curl_easy_setopt(curl, CURLOPT_WRITEDATA, &curldata);
+		curl_easy_setopt(curl, CURLOPT_FAILONERROR, 1);
+		curl_easy_setopt(curl, CURLOPT_TIMEOUT, 150L);
+		curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT, 15L);
+
+		res = curl_easy_perform(curl);
+
+		if (res != CURLE_OK) {
+
+			hildon_banner_show_information(
+					GTK_WIDGET(data->window),
+					NULL,
+					_("An error occured while requesting data over the internet."));
+			gtk_widget_hide(data->currentDialog);
+			gtk_widget_destroy(data->currentDialog);
+			data->currentDialog = NULL;
+
+			g_debug("CURL_ERROR: %d", res);
+
+			return;
+		}
+
+		/* parseSearchResult(curldata.buf, data); */
+
+		char *detailsFrom =
+					strstr(curldata.buf, "<div id=\"content\">");
+
+		if (detailsFrom) {
+
+			char *detailsTo = strstr(detailsFrom, "</div>");
+			int count = detailsTo - detailsFrom + 6;
+			char detailsData[count];
+			strncpy(detailsData, detailsFrom, count);
+
+			detailsData[count] = '\0';
+
+			char *nbspData[count + 51];
+
+			strcpy(nbspData,
+					"<!DOCTYPE doc [\n <!ENTITY nbsp \"&#160;\" > \n]>\n");
+
+			strcat(nbspData, detailsData);
+
+			xmlDoc *doc = NULL;
+			xmlNode *root_element = NULL;
+
+			/*parse the file and get the DOM */
+			doc = xmlReadDoc(nbspData, NULL, NULL, 0);
+
+			/*Get the root element node */
+			root_element = xmlDocGetRootElement(doc);
+
+			xmlNode *cur_node;
+			xmlNode *sub_node;
+			xmlNode *sub_node2;
+
+			/* Create the Subview for details */
+			data->detailsWindow = HILDON_WINDOW(hildon_stackable_window_new());
+			gtk_window_set_title(GTK_WINDOW (data->detailsWindow),
+					_("Details"));
+
+			GtkCellRenderer     *renderer;
+
+			data->currentDetailsSelector = hildon_gtk_tree_view_new(HILDON_UI_MODE_EDIT);
+
+			data->currentDetailsPannableArea = hildon_pannable_area_new();
+
+			renderer = gtk_cell_renderer_text_new ();
+			gtk_cell_renderer_set_fixed_size(renderer, 100, 200);
+
+			gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (data->currentDetailsSelector),
+													   -1,
+													   "Title",
+													   renderer,
+													   "markup", 0,
+													   "expand", 1,
+													   NULL);
+
+			gtk_tree_view_set_fixed_height_mode(GTK_TREE_VIEW (data->currentDetailsSelector), FALSE);
+
+
+			data->currentDetailsModelStore = gtk_list_store_new (1, G_TYPE_STRING);
+
+			for (cur_node = root_element->children; cur_node; cur_node
+					= cur_node->next) {
+				if (!strcmp(cur_node->name, "p")) {
+
+					g_debug("-------------------");
+					if (!strcmp(cur_node->properties->children->content, "details")) {
+
+						g_debug("----- Detail ----");
+
+
+						/*
+						 * 1. span class="bold" (from)
+						 * 2. a->span (train number)
+						 * 3. text (time and stage)
+						 * 4. span class="red" (error message optional)
+						 * 5. span class="bold" (to)
+						 * 6. text (time and stage)
+						 */
+
+						char *fromStr = "";
+						char *trainStr = "";
+						char *timeFromStr = "";
+						char *infoStr = "";
+						char *toStr = "";
+						char *timeToStr = "";
+
+						for (sub_node = cur_node->children; sub_node; sub_node
+										= sub_node->next) {
+
+							if (!strcmp(sub_node->name, "span")) {
+
+								if (!strcmp(sub_node->properties->children->content, "bold")) {
+
+									if (strcmp(fromStr, "") && !strcmp(toStr, "")) {
+
+										toStr = sub_node->children->content;
+									}
+									if (!strcmp(fromStr, "") && !strcmp(toStr, "")) {
+
+										fromStr = sub_node->children->content;
+									}
+								}
+								if (!strcmp(sub_node->properties->children->content, "red")) {
+
+									infoStr = sub_node->children->content;
+								}
+							}
+
+
+							if (!strcmp(sub_node->name, "a") && !strcmp(trainStr, "")) {
+
+								for (sub_node2 = sub_node->children; sub_node2; sub_node2
+																		= sub_node2->next) {
+
+									if (!strcmp(sub_node2->name, "span") && !strcmp(trainStr, "")) {
+
+										trainStr = sub_node2->children->content;
+									}
+								}
+							}
+
+							if (!strcmp(sub_node->name, "text")) {
+
+								char *testFrom = strstr(sub_node->content, "ab");
+								int found = 0;
+
+								if (testFrom) {
+
+									timeFromStr = testFrom;
+									timeFromStr += 3;
+									found = 1;
+								}
+								testFrom = strstr(sub_node->content, "an");
+
+								if (testFrom) {
+
+									timeToStr = testFrom;
+									timeToStr += 3;
+									found = 1;
+								}
+
+								if (found == 0) {
+
+									timeFromStr = sub_node->content;
+								}
+
+							}
+						}
+
+						GtkTreeIter    iter;
+						char infoLabel[1000];
+						sprintf(infoLabel, "%s %s %s %s -%s", fromStr, timeFromStr, toStr, timeToStr, trainStr);
+
+						/* Append a row and fill in some data */
+						gtk_list_store_append (data->currentDetailsModelStore, &iter);
+						gtk_list_store_set (data->currentDetailsModelStore, &iter,
+										  0, infoLabel,
+										  -1);
+
+						g_debug("From: %s", fromStr);
+						g_debug("FromTime: %s", timeFromStr);
+						g_debug("To: %s", toStr);
+						g_debug("ToTime: %s", timeToStr);
+						g_debug("Train: %s", trainStr);
+						g_debug("Info: %s", infoStr);
+					}
+					if (!strcmp(cur_node->properties->children->content, "connectiondetails")) {
+
+						g_debug("----- ConnectionDetails ----");
+
+						/*
+						 * 1. text starts with "Abfahrt:" (departure)
+						 * 2. text starts with "Ankunft:" (arrival)
+						 * 3. text starts with "Dauer:" (duration)
+						 * 4. text stats with "Hinweis:" (info optional)
+						 * 5. span class="bold" (pricing infos)
+						 */
+
+						char *departureStr = "";
+						char *arrivalStr = "";
+						char *durationStr = "";
+						char *infoStr = "";
+						char *pricingStr = "";
+
+						for (sub_node = cur_node->children; sub_node; sub_node
+										= sub_node->next) {
+
+							if (!strcmp(sub_node->name, "text")) {
+
+								char *testFrom = strstr(sub_node->content, "Abfahrt:");
+								if (testFrom) {
+
+									testFrom += 9;
+									departureStr = testFrom;
+								}
+								testFrom = strstr(sub_node->content, "Ankunft:");
+								if (testFrom) {
+
+									testFrom += 9;
+									arrivalStr = testFrom;
+								}
+								testFrom = strstr(sub_node->content, "Dauer:");
+								if (testFrom) {
+
+									testFrom += 7;
+									durationStr = testFrom;
+								}
+								testFrom = strstr(sub_node->content, "Hinweis:");
+								if (testFrom) {
+
+									testFrom += 9;
+									infoStr = testFrom;
+								}
+							}
+
+							if (!strcmp(sub_node->name, "span")) {
+
+								pricingStr = sub_node->children->content;
+							}
+						}
+
+						g_debug("From: %s", departureStr);
+						g_debug("To: %s", arrivalStr);
+						g_debug("Duration: %s", durationStr);
+						g_debug("Info: %s", infoStr);
+						g_debug("Price: %s", pricingStr);
+
+					}
+				}
+			}
+
+			gtk_tree_view_set_model (GTK_TREE_VIEW (data->currentDetailsSelector), GTK_TREE_MODEL(data->currentDetailsModelStore));
+
+			gtk_container_add(GTK_CONTAINER (data->currentDetailsPannableArea), data->currentDetailsSelector);
+
+			gtk_container_add(GTK_CONTAINER (data->detailsWindow), data->currentDetailsPannableArea);
+
+			gtk_widget_show_all(GTK_WIDGET(data->detailsWindow));
+		}
+	}
+}
+
+/**
+ * Function to handle the selection of an entry of the results page
+ */
+void resultSelected(GtkTreeView * selector, GtkTreePath *arg1, AppData *data) {
+
+
+	gchar *current_selection;
+
+	gint num = (gtk_tree_path_get_indices (arg1))[0];
+
+
+	char urlLabel[100];
+
+	sprintf(urlLabel, "URL%d", num + 1);
+
+	current_selection = g_object_get_data(G_OBJECT(data->currentResultSelector), urlLabel);
+
+	/*
+	hildon_banner_show_information(GTK_WIDGET(data->window), NULL,
+			current_selection);
+	*/
+
+	loadDetails(current_selection, data);
+}
+
+/**
+ * Parse the search result itself
+ */
+void parseSearchResult(char *returnData, AppData * data) {
+
+	/* check errors */
+	char *errorDataFrom = strstr(returnData, "<span class=\"error\">");
+
+	if (errorDataFrom) {
+
+		char *errorDataTo = strstr(errorDataFrom, "</span>");
+		int count = errorDataTo - errorDataFrom + 7;
+		char errorData[count];
+		strncpy(errorData, errorDataFrom, count);
+
+		errorData[count] = '\0';
+
+		xmlDoc *doc = NULL;
+		xmlNode *root_element = NULL;
+
+		/*parse the file and get the DOM */
+		doc = xmlReadDoc(errorData, NULL, NULL, 0);
+
+		/*Get the root element node */
+		root_element = xmlDocGetRootElement(doc);
+
+		hildon_banner_show_information(GTK_WIDGET(data->window), NULL,
+				root_element->children->content);
+
+		return;
+	}
+
+	/* Create the Subview for results */
+	data->resultWindow = HILDON_WINDOW(hildon_stackable_window_new());
+	gtk_window_set_title(GTK_WINDOW (data->resultWindow),
+			_("Results"));
+
+	GtkWidget *vbox;
+	GtkWidget *hbox;
+	GtkWidget *infoLabel;
+	GtkWidget *infoLabel2;
+
+	vbox = gtk_vbox_new(FALSE, 0);
+	hbox = gtk_hbox_new(FALSE, 0);
+
+	/* GET HEADER */
+
+	/* g_debug("RESULT: %s", curldata.buf); */
+
+	char *headerDataFrom = strstr(returnData, "<p class=\"qs\">");
+
+	if (headerDataFrom) {
+
+		char *headerDataTo = strstr(headerDataFrom, "</p>");
+		int count = headerDataTo - headerDataFrom + 4;
+		char headerData[count];
+		strncpy(headerData, headerDataFrom, count);
+
+		headerData[count] = '\0';
+
+		/* g_debug("RESULT: %s", headerData); */
+
+		xmlDoc *doc = NULL;
+		xmlNode *root_element = NULL;
+
+		/*parse the file and get the DOM */
+		doc = xmlReadDoc(headerData, NULL, NULL, 0);
+
+		/*Get the root element node */
+		root_element = xmlDocGetRootElement(doc);
+
+		xmlNode *cur_node = NULL;
+
+		int num = 0;
+		char *fromHeaderText;
+		char *toHeaderText;
+		char *timeHeaderText;
+
+		for (cur_node = root_element->children; cur_node; cur_node
+				= cur_node->next) {
+
+			if (!strcmp(cur_node->name, "span")) {
+
+				num++;
+				/* g_debug("X: %s", cur_node->children->content); */
+
+				switch (num) {
+
+				case 1:
+					fromHeaderText = cur_node->children->content;
+					break;
+				case 2:
+					toHeaderText = cur_node->children->content;
+					break;
+				case 3:
+					timeHeaderText = cur_node->children->content;
+					break;
+				}
+			}
+		}
+
+		char infoLabelText[100];
+
+		sprintf(infoLabelText, "%s %s %s %s", _("From: "), fromHeaderText, _("To: "), toHeaderText);
+
+		infoLabel = gtk_label_new(infoLabelText);
+
+		gtk_box_pack_start(GTK_BOX (vbox), infoLabel, FALSE, TRUE, 5);
+
+		infoLabel2 = gtk_label_new(timeHeaderText);
+
+		gtk_box_pack_start(GTK_BOX (vbox), infoLabel2, FALSE, TRUE, 5);
+
+
+	} else {
+
+		hildon_banner_show_information(GTK_WIDGET(data->window), NULL,
+				_("An unknown error occured."));
+		return;
+	}
+
+	/* later and earlier buttons */
+
+	char *resultButtonsFrom =
+				strstr(returnData, "<div id=\"content\">");
+
+	if (resultButtonsFrom) {
+
+		char *resultButtonsTo = strstr(resultButtonsFrom, "</div>");
+		int count = resultButtonsTo - resultButtonsFrom + 6;
+		char resultButtons[count];
+		strncpy(resultButtons, resultButtonsFrom, count);
+
+		resultButtons[count] = '\0';
+
+		char *nbspData[count + 51];
+
+		strcpy(nbspData,
+				"<!DOCTYPE doc [\n <!ENTITY nbsp \"&#160;\" > \n]>\n");
+
+		strcat(nbspData, resultButtons);
+
+		xmlDoc *doc = NULL;
+		xmlNode *root_element = NULL;
+
+		/*parse the file and get the DOM */
+		doc = xmlReadDoc(nbspData, NULL, NULL, 0);
+
+		/*Get the root element node */
+		root_element = xmlDocGetRootElement(doc);
+
+		xmlNode *cur_node = NULL;
+		xmlNode *sub_node = NULL;
+		xmlAttr *cur_attribute = NULL;
+
+		data->currentResultBaseUrl[0] = '\0';
+
+		for (cur_node = root_element->children; cur_node; cur_node
+				= cur_node->next) {
+			if (!strcmp(cur_node->name, "p")) {
+
+				for (sub_node = cur_node->children; sub_node; sub_node
+								= sub_node->next) {
+
+
+					if (!strcmp(sub_node->name, "a")) {
+
+						for (cur_attribute = sub_node->properties; cur_attribute; cur_attribute
+														= cur_attribute->next) {
+
+							if (!strcmp(cur_attribute->name, "href")) {
+
+								char testStr[strlen(cur_attribute->children->content)];
+								strcpy(testStr, cur_attribute->children->content);
+
+								char *testStrLater = strstr(testStr, "e=1");
+								if (testStrLater) {
+
+									testStr[strlen(testStr) - strlen(testStrLater)] = '\0';
+									strcpy(data->currentResultBaseUrl,testStr);
+								}
+							}
+						}
+
+					}
+				}
+			}
+		}
+
+		if (strlen(data->currentResultBaseUrl) > 0) {
+
+			GtkWidget * button;
+			HildonAppMenu *menu = HILDON_APP_MENU (hildon_app_menu_new ());
+
+			/* earlier button */
+			button = hildon_gtk_button_new(HILDON_SIZE_AUTO);
+				gtk_button_set_label(GTK_BUTTON (button), _("Earlier"));
+
+			/* Attach callback to clicked signal */
+			g_signal_connect_after (button, "clicked", G_CALLBACK (earlierClicked), data);
+
+			/* Add entry to the view menu */
+			hildon_app_menu_append(menu, GTK_BUTTON (button));
+
+			/* later button */
+
+			button = hildon_gtk_button_new(HILDON_SIZE_AUTO);
+			gtk_button_set_label(GTK_BUTTON (button), _("Later"));
+
+			/* Attach callback to clicked signal */
+			g_signal_connect_after (button, "clicked", G_CALLBACK (laterClicked), data);
+
+			/* Add entry to the view menu */
+			hildon_app_menu_append(menu, GTK_BUTTON (button));
+
+			gtk_widget_show_all(GTK_WIDGET (menu));
+
+			hildon_window_set_app_menu (HILDON_WINDOW (data->resultWindow), menu);
+		}
+	}
+
+
+	/* RESULTS ITSELF */
+
+	char *resultDataFrom =
+			strstr(returnData, "<table class=\"ovTable\">");
+
+	if (resultDataFrom) {
+
+		char *resultDataTo = strstr(resultDataFrom, "</table>");
+		int count = resultDataTo - resultDataFrom + 8;
+		char resultData[count];
+		strncpy(resultData, resultDataFrom, count);
+
+		resultData[count] = '\0';
+
+		char *nbspData[count + 51];
+
+		strcpy(nbspData,
+				"<!DOCTYPE doc [\n <!ENTITY nbsp \"&#160;\" > \n]>\n");
+
+		strcat(nbspData, resultData);
+
+		/* g_debug("RESULT: %s", nbspData); */
+
+		xmlDoc *doc = NULL;
+		xmlNode *root_element = NULL;
+
+		/*parse the file and get the DOM */
+		doc = xmlReadDoc(nbspData, NULL, NULL, 0);
+
+		/*Get the root element node */
+		root_element = xmlDocGetRootElement(doc);
+
+		GtkCellRenderer     *renderer;
+
+		data->currentResultSelector = hildon_gtk_tree_view_new(HILDON_UI_MODE_EDIT);
+		data->currentResultPannableArea = hildon_pannable_area_new();
+
+		renderer = gtk_cell_renderer_text_new ();
+		gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (data->currentResultSelector),
+												   -1,
+												   "Title",
+												   renderer,
+												   "markup", 0,
+												   NULL);
+
+		data->currentResultModelStore = gtk_list_store_new (1, G_TYPE_STRING);
+
+		getResultValues(root_element->children, data);
+
+		gtk_tree_view_set_model (GTK_TREE_VIEW (data->currentResultSelector), GTK_TREE_MODEL(data->currentResultModelStore));
+
+		/*
+		 * Details page not yet finished so disable
+		g_signal_connect (data->currentResultSelector, "hildon-row-tapped",  G_CALLBACK (resultSelected), data);
+		*/
+
+		gtk_container_add(GTK_CONTAINER (data->currentResultPannableArea), data->currentResultSelector);
+
+		gtk_box_pack_start(GTK_BOX (vbox), data->currentResultPannableArea, TRUE,
+							TRUE, 0);
+
+
+	}
+
+	/* Show Results */
+	gtk_container_add(GTK_CONTAINER (data->resultWindow), vbox);
+
+	gtk_widget_show_all(GTK_WIDGET(data->resultWindow));
 }
 
 /**
  * preform the search itself
  */
-static void performSearch(gchar *fromText, gchar *toText, AppData * data,
-		gint byValue, gchar * targetUrl) {
-
-	/* Set process indicator */
-	hildon_gtk_window_set_progress_indicator(GTK_WINDOW(data->window), 1);
+static void performSearch(gchar *fromText, gchar *toText, AppData * data, gint byValue, gchar * targetUrl) {
 
 	if (!targetUrl) {
 
@@ -343,9 +1094,6 @@ static void performSearch(gchar *fromText, gchar *toText, AppData * data,
 			return;
 		}
 
-		/* Hide process indicator */
-		hildon_gtk_window_set_progress_indicator(GTK_WINDOW(data->window), 0);
-
 		char *selectBoxFrom = strstr(curldata.buf,
 				"<select class=\"tpLocList\" name=\"REQ0JourneyStopsS0K\">");
 		char *selectBoxTo = strstr(curldata.buf,
@@ -473,158 +1221,8 @@ static void performSearch(gchar *fromText, gchar *toText, AppData * data,
 			return;
 		}
 
-		/* check errors */
-		char *errorDataFrom = strstr(curldata.buf, "<span class=\"error\">");
+		parseSearchResult(curldata.buf, data);
 
-		if (errorDataFrom) {
-
-			char *errorDataTo = strstr(errorDataFrom, "</span>");
-			int count = errorDataTo - errorDataFrom + 7;
-			char errorData[count];
-			strncpy(errorData, errorDataFrom, count);
-
-			errorData[count] = '\0';
-
-			xmlDoc *doc = NULL;
-			xmlNode *root_element = NULL;
-
-			/*parse the file and get the DOM */
-			doc = xmlReadDoc(errorData, NULL, NULL, 0);
-
-			/*Get the root element node */
-			root_element = xmlDocGetRootElement(doc);
-
-			hildon_banner_show_information(GTK_WIDGET(data->window), NULL,
-					root_element->children->content);
-
-			return;
-		}
-
-		/* Create the Subview for results */
-		data->resultWindow = HILDON_WINDOW(hildon_stackable_window_new());
-		gtk_window_set_title(GTK_WINDOW (data->resultWindow),
-				_("Fahrplan for maemo / Results"));
-
-		GtkWidget *vbox;
-		GtkWidget *fromLabel;
-		GtkWidget *toLabel;
-		GtkWidget *dateLabel;
-
-		vbox = gtk_vbox_new(FALSE, 0);
-
-		/* GET HEADER */
-
-		g_debug("RESULT: %s", curldata.buf);
-
-		char *headerDataFrom = strstr(curldata.buf, "<p class=\"qs\">");
-
-		if (headerDataFrom) {
-
-			char *headerDataTo = strstr(headerDataFrom, "</p>");
-			int count = headerDataTo - headerDataFrom + 4;
-			char headerData[count];
-			strncpy(headerData, headerDataFrom, count);
-
-			headerData[count] = '\0';
-
-			/* g_debug("RESULT: %s", headerData); */
-
-			xmlDoc *doc = NULL;
-			xmlNode *root_element = NULL;
-
-			/*parse the file and get the DOM */
-			doc = xmlReadDoc(headerData, NULL, NULL, 0);
-
-			/*Get the root element node */
-			root_element = xmlDocGetRootElement(doc);
-
-			xmlNode *cur_node = NULL;
-
-			int num = 0;
-
-			for (cur_node = root_element->children; cur_node; cur_node
-					= cur_node->next) {
-
-				if (!strcmp(cur_node->name, "span")) {
-
-					num++;
-					g_debug("X: %s", cur_node->children->content);
-
-					switch (num) {
-
-					case 1:
-						fromLabel = gtk_label_new(cur_node->children->content);
-						break;
-					case 2:
-						toLabel = gtk_label_new(cur_node->children->content);
-						break;
-					case 3:
-						dateLabel = gtk_label_new(cur_node->children->content);
-						break;
-					}
-				}
-			}
-
-			gtk_box_pack_start(GTK_BOX (vbox), fromLabel, FALSE, TRUE, 0);
-			gtk_box_pack_start(GTK_BOX (vbox), toLabel, FALSE, TRUE, 0);
-			gtk_box_pack_start(GTK_BOX (vbox), dateLabel, FALSE, TRUE, 0);
-		} else {
-
-			hildon_banner_show_information(GTK_WIDGET(data->window), NULL,
-					_("An unknown error occured."));
-			return;
-		}
-
-		/* RESULTS ITSELF */
-
-		char *resultDataFrom =
-				strstr(curldata.buf, "<table class=\"ovTable\">");
-
-		if (resultDataFrom) {
-
-			char *resultDataTo = strstr(resultDataFrom, "</table>");
-			int count = resultDataTo - resultDataFrom + 8;
-			char resultData[count];
-			strncpy(resultData, resultDataFrom, count);
-
-			resultData[count] = '\0';
-
-			char *nbspData[count + 51];
-
-			strcpy(nbspData,
-					"<!DOCTYPE doc [\n <!ENTITY nbsp \"&#160;\" > \n]>\n");
-
-			strcat(nbspData, resultData);
-
-			/* g_debug("RESULT: %s", nbspData); */
-
-			xmlDoc *doc = NULL;
-			xmlNode *root_element = NULL;
-
-			/*parse the file and get the DOM */
-			doc = xmlReadDoc(nbspData, NULL, NULL, 0);
-
-			/*Get the root element node */
-			root_element = xmlDocGetRootElement(doc);
-
-			/* Create a new pannable area. */
-			data->currentPannableArea = hildon_pannable_area_new();
-			data->currentPannableAreaVbox = gtk_vbox_new(FALSE, 2);
-
-			getResultValues(root_element->children, data);
-
-			hildon_pannable_area_add_with_viewport(
-					HILDON_PANNABLE_AREA (data->currentPannableArea),
-					data->currentPannableAreaVbox);
-
-			gtk_box_pack_start(GTK_BOX (vbox), data->currentPannableArea, TRUE,
-					TRUE, 0);
-		}
-
-		/* Show Results */
-		gtk_container_add(GTK_CONTAINER (data->resultWindow), vbox);
-
-		gtk_widget_show_all(GTK_WIDGET(data->resultWindow));
 	}
 }
 
@@ -694,13 +1292,6 @@ void getStationsByName(GtkWidget *w, AppData * data) {
 	gchar *searchFor = hildon_entry_get_text(
 			HILDON_ENTRY(data->currentSearchTextBox));
 
-	/* Set process indicator */
-	hildon_gtk_window_set_progress_indicator(GTK_WINDOW(data->currentDialog), 1);
-
-	/* Hide elements */
-	gtk_widget_hide(GTK_WIDGET (GTK_DIALOG(data->currentDialog)->vbox));
-	gtk_widget_hide(w);
-
 	/* Start Curl search */
 	CURL *curl;
 	CURLcode res;
@@ -887,8 +1478,7 @@ void getByGPS(GtkWidget *w, AppData * data) {
 
 		char url[1000];
 
-		int
-				urlCount =
+		int	urlCount =
 						sprintf(
 								url,
 								"http://mobile.bahn.de/bin/mobil/query.exe/dox?rt=1&use_realtime_filter=1&stationNear=1&look_x=%d&look_y=%d&performLocating=2&tpl=stopsnear&look_maxdist=1000&look_stopclass=1023&n=1",
@@ -1059,6 +1649,8 @@ void showSearchTextBoxDialog(GtkWidget *w, AppData * data) {
 
 	g_signal_connect (G_OBJECT (gpsButton), "clicked", G_CALLBACK (getByGPS), data);
 
+	g_signal_connect (G_OBJECT (data->currentSearchTextBox), "activate", G_CALLBACK (getStationsByName), data);
+
 	gtk_box_pack_start(GTK_BOX (GTK_DIALOG(data->currentDialog)->vbox),
 			submitButton, TRUE, TRUE, 0);
 
@@ -1152,7 +1744,7 @@ void initGui(AppData *data) {
 
 	/* Create the hildon program and setup the title */
 	data->program = HILDON_PROGRAM(hildon_program_get_instance());
-	g_set_application_name(_("Fahrplan for maemo"));
+	g_set_application_name(_("Fahrplan"));
 
 	/* Create HildonWindow and set it to HildonProgram */
 	data->window = HILDON_WINDOW(hildon_stackable_window_new());
@@ -1275,6 +1867,16 @@ void initGui(AppData *data) {
 	hildon_window_set_app_menu (HILDON_WINDOW (data->window), menu);
 
 	gtk_widget_show_all(GTK_WIDGET ( data->window ));
+
+
+/*
+	hildon_button_set_value(HILDON_BUTTON(data->fromButton),
+					"Berlin-Tempelhof");
+
+	hildon_button_set_value(HILDON_BUTTON(data->toButton),
+						"Feldkirchen Blindenschuhle, Neuwied");
+
+*/
 }
 
 /**
